# The Grit Holdings SDK for Python

This is the Grit Holdings Software Development Kit (SDK) for Python.

# Getting Started

Assuming that you have a supported version of Python installed, you can first set up your environment with:

```
$ python3 -m venv env
...
$ . env/bin/activate
$ pip install -r requirements.txt
$ python3 examples.py
```

# More Resources

- Visit [documentation](https://gritholdings.gitbook.io/docs)
- Visit [website](https://www.meetgrit.com)
- Visit [linkedin](https://www.linkedin.com/company/gritholdings)